subscriptions_schema = [
    "billing_cycle_anchor",
    "billing_thresholds",
    "cancel_at",
    "cancel_at_period_end",
    "canceled_at",
    "collection_method",
    "created",
    "current_period_end",
    "current_period_start",
    "customer_address_city",
    "customer_address_country",
    "customer_discount",
    "customer_email",
    "customer_id",
    "customer_invoice_prefix",
    "days_until_due",
    "default_payment_method",
    "default_source",
    "default_tax_rate",
    "discount",
    "ended_at",
    "id",
    "items_data_plan_amount_decimal",
    "items_data_plan_currency",
    "items_data_plan_id",
    "items_data_plan_interval",
    "items_data_plan_interval_count",
    "items_data_plan_metadata_maxSpaceBytes",
    "items_data_plan_metadata_name",
    "items_data_plan_metadata_planType",
    "items_data_plan_product",
    "items_data_price_",
    "items_data_price_id",
    "items_data_price_metadata_maxSpaceBytes",
    "items_data_price_metadata_name",
    "items_data_price_metadata_planType",
    "items_data_price_product",
    "items_data_price_recurring_interval",
    "items_data_price_recurring_interval_count",
    "items_data_price_unit_amount",
    "items_data_price_subscription",
    "latest_invoice",
    "start_date",
    "status"
]
